@@ -182,42 +182,8 @@ matrixpls.sim <- function(nRep = NULL, model = NULL, n = NULL, ..., cilevel = 0.
       matrixpls.res  <- boot.out$t0
     }
     
-    # Check for inadmissible solutions. 
-    #
-    # 0: Converged normally 
-    # 1: Non-convergent result
-    # 2: Non-converged imputation (not used)
-    # 3: At least one SE is negative or NA (not used)
-    # 4: At least one variance estimate is negative
-    # 5: At least one correlation estimate is greater than 1 or less than -1
-    
-    # Non-iterative weight functiosn do not return convergence status so both NULL
-    # and TRUE are considered as converged
-    
-    if(is.null(attr(matrixpls.res,"converged")) ||
-       attr(matrixpls.res,"converged")){
-      
-      converged <- 0
-      
-      C <- attr(matrixpls.res,"C")
-      
-      if(max(abs(C[lower.tri(C)]))>1){
-        converged <- 5 
-      }
-      # If the model is estimated with 2SLS, then checking C is not enough to check for admissible
-      # solution. We need to calculate the explained variances of the endogenous composites
-      
-      else{
-        inner <- attr(matrixpls.res,"inner")
-        if(any(diag(inner%*%C%*%t(inner)) > 1)){
-          converged <- 4
-        }
-      }
-    }
-    else converged <- 1
-    
     ret <- list(coef = matrixpls.res[parameterIndices],
-                converged = converged)
+                converged = convergenceStatus(matrixpls.res))
     
     # If the data were generated sequentially using LV scores, calculate the true reliabilities
     
